pub enum Objective {
VisitAllNodes,
VisitNNodes(usize),
ReachNodeIdx(usize),
ReachDeadEnd,
}Variants
VisitAllNodes
Visit all of the nodes of the graph (will fail on an incomplete graph)
VisitNNodes(usize)
Visit exactly this many nodes of the graph
ReachNodeIdx(usize)
Visit node indexed by the provided index
ReachDeadEnd
Reach a dead end, this can be useful for going as far down as possible